#!/bin/bash

# Exit immediately on uninitialized variable or error, and print each command.
set -uex

drush sql:query --database=migrate "
  SELECT
    q.nid AS node_id,
    q.uid AS user_id,
    lower(fdf_pmn.field_project_machine_name_value) AS machine_name,
    fdf_is.field_issue_status_value IN (3,5,6,18,17,7,2) AS closed,
    if(q.uid = 0, 0, max(coalesce(c.cid = fdf_ic.field_issue_credit_target_id, 0))) AS credited,
    coalesce(sum(fdf_aav.field_attribute_as_volunteer_value = 1) > 0, 0) AS as_volunteer,
    coalesce(sum(fdf_aav.field_attribute_as_volunteer_value = 0) > 0, 0) AS to_organization,
    group_concat(DISTINCT n_o.nid ORDER BY n_o.nid) AS organizations,
    group_concat(DISTINCT n_c.nid ORDER BY n_c.nid) AS customers,
    q.type IN ('sa') AS is_sa
  FROM (SELECT DISTINCT inner_q.* FROM (
    SELECT -- commenting users
      n.nid,
      c.uid,
      n.type
    FROM node n
    INNER JOIN comment c ON c.nid = n.nid AND c.status = 1 AND c.uid > 0 AND c.uid IS NOT NULL
    WHERE n.status = 1 AND (n.type = 'project_issue' OR n.type = 'sa')
    GROUP BY n.nid, c.uid
    UNION SELECT -- author
      n.nid,
      n.uid,
      n.type
    FROM node n
    WHERE n.status = 1 AND n.uid > 0 AND (n.type = 'project_issue' OR n.type = 'sa')
    UNION SELECT -- anonymous fallback
      n.nid,
      n.uid,
      n.type
    FROM node n
    LEFT JOIN comment c ON c.nid = n.nid AND c.status = 1 AND c.uid > 0 AND c.uid IS NOT NULL
    WHERE n.status = 1 AND n.uid = 0 AND c.uid IS NULL AND (n.type = 'project_issue' OR n.type = 'sa')
  ) inner_q) q
  INNER JOIN users u ON u.uid = q.uid
  LEFT JOIN field_data_field_project fdf_p ON fdf_p.entity_id = q.nid AND (fdf_p.bundle = 'project_issue' OR fdf_p.bundle = 'sa')
  LEFT JOIN field_data_field_project_machine_name fdf_pmn ON fdf_pmn.entity_id = fdf_p.field_project_target_id
  LEFT JOIN field_data_field_issue_status fdf_is ON fdf_is.entity_id = q.nid
  LEFT JOIN comment c ON c.nid = q.nid AND c.uid = q.uid AND c.status = 1
  LEFT JOIN field_data_field_issue_credit fdf_ic ON fdf_ic.field_issue_credit_target_id = c.cid
  LEFT JOIN field_data_field_attribute_as_volunteer fdf_aav ON fdf_aav.entity_id = c.cid
  LEFT JOIN field_data_field_attribute_contribution_to fdf_act ON fdf_act.entity_id = c.cid
  LEFT JOIN node n_o ON n_o.nid = fdf_act.field_attribute_contribution_to_target_id
  LEFT JOIN field_data_field_for_customer fdf_fc ON fdf_fc.entity_id = c.cid
  LEFT JOIN node n_c ON n_c.nid = fdf_fc.field_for_customer_target_id
  GROUP BY node_id, user_id
  ORDER BY node_id, user_id;
" > d7.tsv &

drush sql:query "
  SELECT
    cast(REPLACE(fsl.field_source_link_uri, 'https://www.drupal.org/node/', '') AS unsigned) AS node_id,
    coalesce(fcu.field_contributor_user_target_id, 0) AS user_id,
    LOWER(nf_pn.field_project_name_value),
    NOT nf_d.field_draft_value AS closed,
    coalesce(fctc.field_credit_this_contributor_value, 0) AS credited,
    coalesce(fcv.field_contributor_volunteer_value, 0) AS as_volunteer,
    coalesce(fcao.field_contributor_attribute_orgs_value, 0) AS to_organization,
    group_concat(DISTINCT fco.field_contributor_organisation_target_id ORDER BY fco.field_contributor_organisation_target_id) organizations,
    group_concat(DISTINCT fcc.field_contributor_customer_target_id ORDER BY fcc.field_contributor_customer_target_id) customers,
    max(coalesce(nf_sa.field_is_sa_value, 0)) AS is_sa
  FROM node__field_source_link fsl
  LEFT JOIN node__field_contributors fc ON fsl.entity_id = fc.entity_id
  LEFT JOIN paragraph__field_contributor_user fcu ON fc.field_contributors_target_id = fcu.entity_id
  LEFT JOIN node__field_project_name nf_pn ON nf_pn.entity_id = fsl.entity_id
  LEFT JOIN node__field_draft nf_d ON nf_d.entity_id = fsl.entity_id
  LEFT JOIN node__field_is_sa nf_sa ON fsl.entity_id = nf_sa.entity_id
  LEFT JOIN paragraph__field_contributor_volunteer fcv ON fc.field_contributors_target_id = fcv.entity_id
  LEFT JOIN paragraph__field_contributor_attribute_orgs fcao ON fc.field_contributors_target_id = fcao.entity_id
  LEFT JOIN paragraph__field_contributor_organisation fco ON fc.field_contributors_target_id = fco.entity_id
  LEFT JOIN paragraph__field_contributor_customer fcc ON fc.field_contributors_target_id = fcc.entity_id
  LEFT JOIN paragraph__field_credit_this_contributor fctc ON fc.field_contributors_target_id = fctc.entity_id
  GROUP BY node_id, user_id
  ORDER BY node_id, user_id;
" > d10.tsv

wait

diff -u d7.tsv d10.tsv > contrib-results.diff
