<?php

/**
 * @file
 * Process a diff file generated by querying the legacy and modern databases.
 */

ini_set("memory_limit", "1000M");

/**
 * Whether to process rows from the diff file or not.
 *
 * @param array $row
 *   Row from the diff file.
 *
 * @return bool
 *   Whether we should discard this row or not.
 */
function discard_row($row) {
  // Discard non-diff lines.
  $discard_these = ['---', '+++', '@@', ' '];
  $as_string = implode(' ', $row);
  foreach ($discard_these as $value) {
    if (str_starts_with($as_string, $value)) {
      return TRUE;
    }
  }

  // 10 is the number of columns returned in the query.
  return (count($row) !== 10);
}

/**
 * Generates a self-healing command for the given records.
 *
 * @param array $nids
 *   List of nodes.
 *
 * @return string
 *   Output command.
 */
function generate_resync_command($nids) {
  $output = '';
  $command = 'drush contribution_records:sync-contribution-records --hard-reset=1 --nids=';
  $chunks = array_chunk($nids, 1000);
  foreach ($chunks as $chunk) {
    $output .= $command . implode(',', $chunk) . PHP_EOL;
  }

  return $output;
}

// Open the file and process it.
$inputFile = 'contrib-results.diff';
$handle = fopen($inputFile, 'r');
if (!$handle) {
  die("Failed to open input file.\n");
}
$reported_nids = [];
while (($current_row = fgetcsv($handle, 0, "\t", '"', "\\")) !== FALSE) {
  if (discard_row($current_row)) {
    continue;
  }

  $int_value = (int) $current_row[0];
  $nid = abs($int_value);
  $reported_nids[$nid] = TRUE;
}
fclose($handle);

$total_nids = count($reported_nids);

echo 'CONTRIBUTION RECORDS DIFF. Total: ' . $total_nids . PHP_EOL;
if ($total_nids > 5) {
  echo '[ALERT] Contribution records mismatch between legacy and modern system. ' . $total_nids . ' records are different.' . PHP_EOL . PHP_EOL;
  echo generate_resync_command(array_keys($reported_nids)) . PHP_EOL;
}
